@@ -4,3 +4,8 @@ LastEditors: ThetisEliza wxf199601@gmail.com
 LastEditTime: 2023-03-14 17:57:14
 FilePath: /outlier/src/outlier/__init__.py
 '''
+
+__all__ = ['server', 'client']
+
+from . import server
+from . import client
