@@ -1,13 +1,15 @@
 '''
 Date: 2023-03-08 23:10:22
 LastEditors: ThetisEliza wxf199601@gmail.com
-LastEditTime: 2023-03-09 16:55:08
+LastEditTime: 2023-03-14 18:06:36
 FilePath: /outlier/src/outlier/tools/utils.py
 '''
 import logging
-from logging import handlers
+import hashlib
+import random
 import socket
-import sys
+from logging import handlers
+from datetime import datetime
 
 FORMAT = '%(asctime)s - %(message)s'
 
@@ -28,8 +30,7 @@ def initlogger(level, format=FORMAT, filehandlename=None):
         logging.basicConfig(format=format, level=eval("logging."+level), handlers=[handlers.RotatingFileHandler(filehandlename, maxBytes=500000, backupCount=20)])
     else:
         logging.basicConfig(format=format, level=eval("logging."+level))
-    
-    
+  
  
 def gethostaddr() -> str:
     """This function is to check the ipaddress that a host should be bind
@@ -40,4 +41,10 @@ def gethostaddr() -> str:
     with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as s:
         s.connect(('8.8.8.8', 80))
         ip = s.getsockname()
-        return ip[0]
\ No newline at end of file
+        return ip[0]
+    
+
+class RandomGen:
+    @staticmethod
+    def getrandomvalue():
+        return hashlib.md5(str(random.randint(0, 1024) + datetime.now().timestamp()).encode()).hexdigest()
\ No newline at end of file
